/*------------------------------------------------------------------*/
/* Large LED display sample 2                                        */
/*------------------------------------------------------------------*/
#define LED7SEG_ENABLE  12
#define LED7SEG_DATA    11
#define LED7SEG_CLOCK   10

#define CMD_NORMAL       0b00010000
#define CMD_NORMAL_DP    0b00100000
#define CMD_CODE         0b01110000
#define CMD_ID           0b10000000

#define CMD_ASCII           0
#define CMD_MAX7219         1
#define CMD_ASCII_ROTATE    2
#define CMD_MAX7219_ROTATE  3

#define Digit_0       0x7E
#define Digit_1       0x30
#define Digit_2       0x6D
#define Digit_3       0x79
#define Digit_4       0x33
#define Digit_5       0x5B
#define Digit_6       0x5F
#define Digit_7       0x70
#define Digit_8       0x7F
#define Digit_9       0x7B
#define Digit_E       0x4F
#define Digit_F       0x47
#define Digit_U       0x3E
#define Digit_u       0x1C
#define Digit_L       0x0E
#define Digit_C       0x4E
#define Digit_P       0x67
#define Digit_Y       0x3B
#define Digit_A       0x77
#define Digit_a       0x7D
#define Digit_r       0x05
#define Digit_n       0x15
#define Digit_d       0x3D
#define Digit_t       0x0F
#define Digit_G       0x5E
#define Digit_b       0x1F
#define Digit_i       0x04
#define Digit_l       0x30
#define Digit_NON     0x00
#define Digit_o       0x1D
#define Digit_S       0x5B
#define Digit_h       0x17
#define Digit_H       0x37
#define Digit_c       0x0D
#define Digit_J       0x3C
#define Digit_US      0x08
#define Digit_MINUS   0x01
#define Digit_DP      0x80

//------------------------------------------------------------------------------
// external LARGE LED display
//------------------------------------------------------------------------------
void led7seg_write( unsigned char data )
{
  digitalWrite(LED7SEG_CLOCK,1);
  delayMicroseconds(1);
  digitalWrite(LED7SEG_ENABLE,0);
  for( unsigned char i = 0 ; i < 8 ; i++ ) {
    digitalWrite(LED7SEG_CLOCK,0);
    if( (data & 0x80) == 0x80 ) {
       digitalWrite(LED7SEG_DATA,1);
    } else {
       digitalWrite(LED7SEG_DATA,0);
    }
    data <<= 1;
    delayMicroseconds(10);  
    digitalWrite(LED7SEG_CLOCK,1);
    delayMicroseconds(10);
  }
  digitalWrite(LED7SEG_ENABLE,1);
  delayMicroseconds(15);
}

//------------------------------------------------------------------------------
// setup
//------------------------------------------------------------------------------
void setup() {
  pinMode(LED7SEG_ENABLE, OUTPUT);     
  pinMode(LED7SEG_CLOCK,  OUTPUT);     
  pinMode(LED7SEG_DATA,   OUTPUT);

  digitalWrite(LED7SEG_ENABLE,1);

  delay(1000);

  //------------ ASCII CODE MODE ---------------------------------
  led7seg_write( CMD_ID | CMD_CODE | 0 );    // display id = 0
  led7seg_write( CMD_ASCII );  
  delay(100); 
  //------------ MAX7219 CODE MODE ---------------------------------
  led7seg_write( CMD_ID | CMD_CODE | 1 );    // display id = 1
  led7seg_write( CMD_MAX7219 );  
  delay(100);   
}

//------------------------------------------------------------------------------
// loop
//------------------------------------------------------------------------------
void loop() {
  for( unsigned char num = 0 ; num <= 9 ; num++ ) {
    led7seg_write( CMD_ID | CMD_NORMAL    | 0 );    // display id = 0
    led7seg_write( num + '0' ); 
//    led7seg_write( CMD_ID | CMD_NORMAL_DP | 1 );    // display id = 0
//    led7seg_write( num + '0' ); 
//    delay(10);
    led7seg_write( CMD_ID | CMD_NORMAL_DP | 1 ); // display id = 0
 //    led7seg_write( num + '0' ); 
    switch( num ) {
      case 0: led7seg_write( Digit_A );     break; 
      case 1: led7seg_write( Digit_U );     break;  
      case 2: led7seg_write( Digit_u );     break;
      case 3: led7seg_write( Digit_d );     break;
      case 4: led7seg_write( Digit_P );     break;
      case 5: led7seg_write( Digit_H );     break;
      case 6: led7seg_write( Digit_h );     break;
      case 7: led7seg_write( Digit_US );    break;
      case 8: led7seg_write( Digit_MINUS ); break;
      case 9: led7seg_write( Digit_L );     break;
    }

    delay(500);
  }
}
